﻿
using System;
using Android.App;
using Android.OS;
using Android.Content.PM;
using Android.Views;
using Android.Graphics;

namespace CameraDroid
{
	[Activity(Label = "カメラ間違い探し", ConfigurationChanges = ConfigChanges.ScreenSize | ConfigChanges.Orientation, ScreenOrientation = ScreenOrientation.Portrait)]
	public class CameraActivity : Activity
	{
		CameraPreview _cameraPreview;
		Speech_Droid _speech = new Speech_Droid();
		Android.Widget.Button _takePhotoButton;
		Android.Widget.Button _answerButton;
		Android.Widget.Button _rightButton;
		Random _rand = new Random();

		protected override void OnCreate(Bundle savedInstanceState)
		{
			base.OnCreate(savedInstanceState);

			_takePhotoButton = new Android.Widget.Button(this);
			_takePhotoButton.SetBackgroundResource(Resource.Drawable.TakePhotoButton);
			_takePhotoButton.Click += TakePhotoButtonTapped;

			_answerButton = new Android.Widget.Button(this);
			_answerButton.Visibility = ViewStates.Invisible;
			_answerButton.SetBackgroundResource(Resource.Drawable.AnswerButton);
			_answerButton.Click += AnswerButtonTapped;

			_rightButton = new Android.Widget.Button(this);
			_rightButton.Visibility = ViewStates.Invisible;
			_rightButton.SetBackgroundResource(Resource.Drawable.RightButton);
			_rightButton.Click += delegate { OnBackPressed(); };

			_cameraPreview = new CameraPreview(this);
			var layout = new Android.Widget.FrameLayout(this);
			layout.AddView(_cameraPreview);
			var param = new Android.Widget.FrameLayout.LayoutParams(200, 200, GravityFlags.Center|GravityFlags.Bottom);
			layout.AddView(_takePhotoButton, param);
			param = new Android.Widget.FrameLayout.LayoutParams(150, 150);
			layout.AddView(_answerButton,param);
			param = new Android.Widget.FrameLayout.LayoutParams(600, 284, GravityFlags.Center);
			layout.AddView(_rightButton, param);
			SetContentView(layout);

			_cameraPreview.Preview = Android.Hardware.Camera.Open();
			_cameraPreview.Click += CameraPreviewTapped;
		}

		protected override void OnPause()
		{
			base.OnPause();

			if (_cameraPreview.Preview != null)
			{
				_cameraPreview.Preview.StopPreview();
				_cameraPreview.Preview.Release();
				_cameraPreview.Preview = null;
			}
		}

		protected override void OnResume()
		{
			base.OnResume();

			if (_cameraPreview.Preview == null)
			{
				_cameraPreview.Preview = Android.Hardware.Camera.Open();
			}
		}

		void CameraPreviewTapped(object sender, EventArgs e)
		{
			if (_takePhotoButton.Visibility == ViewStates.Invisible)
			{
				_speech.Speak(this, "Wrong");
			}
		}

		void TakePhotoButtonTapped(object sender, EventArgs e)
		{
			_cameraPreview.Preview.StopPreview();
			Point size = new Point();
			WindowManager.DefaultDisplay.GetSize(size);
			_answerButton.SetX(_rand.Next(100,size.X - 200));
			_answerButton.SetY(_rand.Next(100, size.Y - 200));
			_answerButton.Visibility = ViewStates.Visible;
			_takePhotoButton.Visibility = ViewStates.Invisible;
		}

		void AnswerButtonTapped(object sender, EventArgs e)
		{
			if (_rightButton.Visibility == ViewStates.Invisible)
			{
				_speech.Speak(this,"Right");
				_rightButton.Visibility = ViewStates.Visible;
			}
		}
	}
}
